==> kubernetes-model-0.1.5-sources.jar: io/fabric8/kubernetes/api/model/EventFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class EventFluent<T extends EventFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     Event.ApiVersion apiVersion;     Integer count;     String firstTimestamp;     VisitableBuilder<ObjectReference, ?> involvedObject;     String kind;     String lastTimestamp;     String message;     VisitableBuilder<ObjectMeta, ?> metadata;     String reason;     EventSource source;     Map<String, Object> additionalProperties = new HashMap();

    public Event.ApiVersion getApiVersion(){
    return this.apiVersion;
    }
    public T withApiVersion( Event.ApiVersion apiVersion){
    this.apiVersion=apiVersion; return (T) this;
    }
    public Integer getCount(){
    return this.count;
    }
    public T withCount( Integer count){
    this.count=count; return (T) this;
    }
    public String getFirstTimestamp(){
    return this.firstTimestamp;
    }
    public T withFirstTimestamp( String firstTimestamp){
    this.firstTimestamp=firstTimestamp; return (T) this;
    }
    public ObjectReference getInvolvedObject(){
    return this.involvedObject!=null?this.involvedObject.build():null;
    }
    public T withInvolvedObject( ObjectReference involvedObject){
    if (involvedObject!=null){ this.involvedObject= new ObjectReferenceBuilder(involvedObject); _visitables.add(this.involvedObject);} return (T) this;
    }
    public InvolvedObjectNested<T> withNewInvolvedObject(){
    return new InvolvedObjectNested<T>();
    }
    public InvolvedObjectNested<T> withNewInvolvedObjectLike( ObjectReference item){
    return new InvolvedObjectNested<T>(item);
    }
    public InvolvedObjectNested<T> editInvolvedObject(){
    return withNewInvolvedObjectLike(getInvolvedObject());
    }
    public String getKind(){
    return this.kind;
    }
    public T withKind( String kind){
    this.kind=kind; return (T) this;
    }
    public String getLastTimestamp(){
    return this.lastTimestamp;
    }
    public T withLastTimestamp( String lastTimestamp){
    this.lastTimestamp=lastTimestamp; return (T) this;
    }
    public String getMessage(){
    return this.message;
    }
    public T withMessage( String message){
    this.message=message; return (T) this;
    }
    public ObjectMeta getMetadata(){
    return this.metadata!=null?this.metadata.build():null;
    }
    public T withMetadata( ObjectMeta metadata){
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (T) this;
    }
    public MetadataNested<T> withNewMetadata(){
    return new MetadataNested<T>();
    }
    public MetadataNested<T> withNewMetadataLike( ObjectMeta item){
    return new MetadataNested<T>(item);
    }
    public MetadataNested<T> editMetadata(){
    return withNewMetadataLike(getMetadata());
    }
    public String getReason(){
    return this.reason;
    }
    public T withReason( String reason){
    this.reason=reason; return (T) this;
    }
    public EventSource getSource(){
    return this.source;
    }
    public T withSource( EventSource source){
    this.source=source; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }

    public class InvolvedObjectNested<N> extends ObjectReferenceFluent<InvolvedObjectNested<N>> implements Nested<N>{

        private final ObjectReferenceBuilder builder;
    
             InvolvedObjectNested (){
        this.builder = new ObjectReferenceBuilder(this);
        }
             InvolvedObjectNested ( ObjectReference item){
        this.builder = new ObjectReferenceBuilder(this, item);
        }
    
            public N endInvolvedObject(){
            return and();
        }
            public N and(){
            return (N) EventFluent.this.withInvolvedObject(builder.build());
        }
    
}
    public class MetadataNested<N> extends ObjectMetaFluent<MetadataNested<N>> implements Nested<N>{

        private final ObjectMetaBuilder builder;
    
             MetadataNested (){
        this.builder = new ObjectMetaBuilder(this);
        }
             MetadataNested ( ObjectMeta item){
        this.builder = new ObjectMetaBuilder(this, item);
        }
    
            public N endMetadata(){
            return and();
        }
            public N and(){
            return (N) EventFluent.this.withMetadata(builder.build());
        }
    
}


}

==> kubernetes-model-1.0.16-sources.jar: io/fabric8/kubernetes/api/model/EventFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class EventFluent<T extends EventFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     Event.ApiVersion apiVersion;     Integer count;     String firstTimestamp;     VisitableBuilder<ObjectReference, ?> involvedObject;     String kind;     String lastTimestamp;     String message;     VisitableBuilder<ObjectMeta, ?> metadata;     String reason;     VisitableBuilder<EventSource, ?> source;     Map<String, Object> additionalProperties = new HashMap();

    public Event.ApiVersion getApiVersion(){
    return this.apiVersion;
    }
    public T withApiVersion( Event.ApiVersion apiVersion){
    this.apiVersion=apiVersion; return (T) this;
    }
    public Integer getCount(){
    return this.count;
    }
    public T withCount( Integer count){
    this.count=count; return (T) this;
    }
    public String getFirstTimestamp(){
    return this.firstTimestamp;
    }
    public T withFirstTimestamp( String firstTimestamp){
    this.firstTimestamp=firstTimestamp; return (T) this;
    }
    public ObjectReference getInvolvedObject(){
    return this.involvedObject!=null?this.involvedObject.build():null;
    }
    public T withInvolvedObject( ObjectReference involvedObject){
    if (involvedObject!=null){ this.involvedObject= new ObjectReferenceBuilder(involvedObject); _visitables.add(this.involvedObject);} return (T) this;
    }
    public InvolvedObjectNested<T> withNewInvolvedObject(){
    return new InvolvedObjectNested<T>();
    }
    public InvolvedObjectNested<T> withNewInvolvedObjectLike( ObjectReference item){
    return new InvolvedObjectNested<T>(item);
    }
    public InvolvedObjectNested<T> editInvolvedObject(){
    return withNewInvolvedObjectLike(getInvolvedObject());
    }
    public String getKind(){
    return this.kind;
    }
    public T withKind( String kind){
    this.kind=kind; return (T) this;
    }
    public String getLastTimestamp(){
    return this.lastTimestamp;
    }
    public T withLastTimestamp( String lastTimestamp){
    this.lastTimestamp=lastTimestamp; return (T) this;
    }
    public String getMessage(){
    return this.message;
    }
    public T withMessage( String message){
    this.message=message; return (T) this;
    }
    public ObjectMeta getMetadata(){
    return this.metadata!=null?this.metadata.build():null;
    }
    public T withMetadata( ObjectMeta metadata){
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (T) this;
    }
    public MetadataNested<T> withNewMetadata(){
    return new MetadataNested<T>();
    }
    public MetadataNested<T> withNewMetadataLike( ObjectMeta item){
    return new MetadataNested<T>(item);
    }
    public MetadataNested<T> editMetadata(){
    return withNewMetadataLike(getMetadata());
    }
    public String getReason(){
    return this.reason;
    }
    public T withReason( String reason){
    this.reason=reason; return (T) this;
    }
    public EventSource getSource(){
    return this.source!=null?this.source.build():null;
    }
    public T withSource( EventSource source){
    if (source!=null){ this.source= new EventSourceBuilder(source); _visitables.add(this.source);} return (T) this;
    }
    public SourceNested<T> withNewSource(){
    return new SourceNested<T>();
    }
    public SourceNested<T> withNewSourceLike( EventSource item){
    return new SourceNested<T>(item);
    }
    public SourceNested<T> editSource(){
    return withNewSourceLike(getSource());
    }
    public T withNewSource( String component,  String host){
    return withSource(new EventSource(component, host));
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
EventFluent that = (EventFluent) o;
if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
if (count != null ? !count.equals(that.count) :that.count != null) return false;
if (firstTimestamp != null ? !firstTimestamp.equals(that.firstTimestamp) :that.firstTimestamp != null) return false;
if (involvedObject != null ? !involvedObject.equals(that.involvedObject) :that.involvedObject != null) return false;
if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
if (lastTimestamp != null ? !lastTimestamp.equals(that.lastTimestamp) :that.lastTimestamp != null) return false;
if (message != null ? !message.equals(that.message) :that.message != null) return false;
if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
if (source != null ? !source.equals(that.source) :that.source != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class InvolvedObjectNested<N> extends ObjectReferenceFluent<InvolvedObjectNested<N>> implements Nested<N>{

        private final ObjectReferenceBuilder builder;
    
             InvolvedObjectNested ( ObjectReference item){
        this.builder = new ObjectReferenceBuilder(this, item);
        }
             InvolvedObjectNested (){
        this.builder = new ObjectReferenceBuilder(this);
        }
    
            public N and(){
            return (N) EventFluent.this.withInvolvedObject(builder.build());
        }
            public N endInvolvedObject(){
            return and();
        }
    
}
    public class MetadataNested<N> extends ObjectMetaFluent<MetadataNested<N>> implements Nested<N>{

        private final ObjectMetaBuilder builder;
    
             MetadataNested (){
        this.builder = new ObjectMetaBuilder(this);
        }
             MetadataNested ( ObjectMeta item){
        this.builder = new ObjectMetaBuilder(this, item);
        }
    
            public N and(){
            return (N) EventFluent.this.withMetadata(builder.build());
        }
            public N endMetadata(){
            return and();
        }
    
}
    public class SourceNested<N> extends EventSourceFluent<SourceNested<N>> implements Nested<N>{

        private final EventSourceBuilder builder;
    
             SourceNested (){
        this.builder = new EventSourceBuilder(this);
        }
             SourceNested ( EventSource item){
        this.builder = new EventSourceBuilder(this, item);
        }
    
            public N and(){
            return (N) EventFluent.this.withSource(builder.build());
        }
            public N endSource(){
            return and();
        }
    
}


}
